<?php

/**
 * @link https://www.humhub.org/
 * @copyright Copyright (c) 2017 HumHub GmbH & Co. KG
 * @license https://www.humhub.com/licences
 */

namespace humhub\modules\cfiles\widgets;

/**
 * Description of FileListWidget
 *
 * @author Luke
 */
class FileListWidget extends \humhub\components\Widget
{

    /**
     * @var \humhub\modules\cfiles\models\Folder
     */
    public $folder;

    /**
     * @var boolean
     */
    public $includeItemCount;

    /**
     * @var 
     */
    public $errorMessages;

    /**
     * @inheritdoc
     */
    public function run()
    {
        if ($this->getCurrentFolder()->isAllPostedFiles()) {
            return $this->renderAllPostedFilesList($withItemCount, $filesOrder, $foldersOrder);
        }

        $items = $this->getItemsList($filesOrder, $foldersOrder);

        return $this->render('@cfiles/views/browse/fileList', [
                    'items' => $this->getItems(),
                    'contentContainer' => $this->folder->content->container,
                    'crumb' => $this->generateCrumb(),
                    'errorMessages' => $this->errorMessages,
                    'currentFolder' => $this->folder,
        ]);
    }

    /**
     * Returns all parent folders as array
     *
     * @return array of parent folders
     */
    protected function generateCrumb()
    {
        $crumb = [];

        $parent = $this->folder;
        do {
            $crumb[] = $parent;
            $parent = $parent->parentFolder;
        } while ($parent != null);

        return array_reverse($crumb);
    }

}
